#!/usr/bin/env python
"""displayLabelsIfNotTooManyPoints.py
Example of use:
Enclose the script within a program block and run it from a syntax window
"""
import spss, spssaux

__author__  =  'Raynald Levesque raynald@spsstools.net'
__version__ =  '1.1'

def doGraphLabel(xVar, yVar, labelVar, title, maxDataPoints=25):
    """ Example of a GGRAPH that labels data points in a scatter plot only when the number of
    data points is less than the number passed as an argument
    This is useful in situations where you only want to plot data for cases meeting a given criteria
    If there are too many cases, you may prefer not to display data labels.
    """
    nbCases = spss.GetCaseCount()
    labelCode = ''
    if nbCases < maxDataPoints:
        labelCode = ", label(%s)" % labelVar # Data labels will be displayed
    #Next line is in case the title includes a double quote (GPL uses \ for escaping ")
    title = title.replace('"', r'\"')
    varDict = spssaux.VariableDict([xVar, yVar, labelVar])
    xVarLab = varDict[xVar].VariableLabel
    yVarLab = varDict[yVar].VariableLabel

    cmd = r"""
        GGRAPH
          /GRAPHDATASET NAME="graphdataset" VARIABLES=%(xVar)s %(yVar)s %(labelVar)s
          MISSING=LISTWISE REPORTMISSING=NO
          /GRAPHSPEC SOURCE=INLINE LABEL="%(title)s".
        BEGIN GPL
         SOURCE: s=userSource(id("graphdataset"))
         DATA: %(xVar)s=col(source(s), name("%(xVar)s"))
         DATA: %(yVar)s=col(source(s), name("%(yVar)s"))
         DATA: %(labelVar)s=col(source(s), name("%(labelVar)s"), unit.category())
         GUIDE: axis(dim(1), label("%(xVarLab)s"))
         GUIDE: axis(dim(2), label("%(yVarLab)s"))
         GUIDE: text.title(label("%(title)s"))
         ELEMENT: point(position(%(xVar)s*%(yVar)s) %(labelCode)s)
        END GPL.""" % locals()
    try:
        spss.Submit(cmd)
    except:
        print '\n*** Following syntax generated an error',cmd
        raise

if __name__ == '__main__':
    xVar = 'density'
    yVar = 'urban'
    labelVar='country'

    spss.Submit(r"""
        SET MPRINT=YES /PRINTBACK=YES.
        GET FILE="C:\Program Files\SPSS\World95.sav".
        """)
    doGraphLabel(xVar, yVar, labelVar,
                 title='More than 25 points, so do not label', maxDataPoints=25)
    # Eliminate some data points to show program works
    spss.Submit(r"""
            SELECT IF $CASENUM < 20.
            EXECUTE.
            """)
    doGraphLabel(xVar, yVar, labelVar,
        title='Less than 25 points, so label using %s' % labelVar, maxDataPoints=25)
